# merqube-client-lib
Merqube API Client Library (Python)

# Overview
This is a WIP release of an internal client library. This README will be updated when it is ready.

# CircleCI
[![CircleCI](https://dl.circleci.com/status-badge/img/gh/merqube/merqube-client-lib/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/merqube/merqube-client-lib/tree/main)
